@@ -44,39 +44,33 @@ echelon.editmatrix <- function(E,...){
 
 #' Write a system of equations in reduced row echelon form
 #'
-#' This function is based on the code of John Fox, see
-#' http://socserv.socsci.mcmaster.ca/jfox/Courses/R-programming/matrixDemos.R
 #'
-#' @param A a matrix
+#' @param E a matrix
+#' @param tol tolerance for checking zero elements in E
 #' @return the matrix in Reduced row echelon form
 #' @nord
 #' @export
-echelon.matrix <- function(E, tol=sqrt(.Machine$double.eps),...){
-    n <- nrow(E)
-    m <- ncol(E)
-    for (i in 1:min(c(m, n))){
-        col <- E[,i]
-        col[1:n < i] <- 0
-    # find maximum pivot in current column at or below current row
-        which <- which.max(abs(col))
-        pivot <- E[which, i]
-        if (abs(pivot) <= tol) next     # check for 0 pivot
-        if (which > i) E[c(i, which),] <- E[c(which, i),]  # exchange rows
-        E[i,] <- E[i,]/pivot            # pivot
-        row <- E[i,]
-        E <- E - outer(E[,i], row)      # sweep
-        E[i,] <- row                    # restore current row
+echelon.matrix <- function(E, tol=sqrt(.Machine$double.eps), ...){
+    k <- min(ncol(E),nrow(E))
+    I <- 1:nrow(E)
+    for ( i in 1:k ){
+        I1 <- which(I >= i)
+        ip <- I1[which.max(abs(E[I1,i]))]
+        p <- E[ip,]
+        if ( abs(p[i]) < tol ) next
+        if ( ip > i ) E[c(ip,i),] <- E[c(i,ip),]
+        E[-i,] <- E[-i,] - outer(E[-i,i],p/p[i])
     }
-    for (i in 1:n){
-        if (max(abs(E[i,1:m])) <= tol)
-            E[c(i,n),] <- E[c(n,i),] # 0 rows to bottom
-    }
-    E[abs(E) <= tol] <- 0
-    return(E) 
+    d <- diag(E)
+    id <- abs(d) > tol
+    E[id,] <- E[id,]/d[id]
+    I0 <- rowSums(abs(E) < tol) == ncol(E)
+    rbind(E[!I0,,drop=FALSE],E[I0,,drop=FALSE])
 }
 
 
 
+
 #' Reduce an editmatrix by substituting a variable
 #'
 #' Given a set of linear restrictions \eqn{E: {\bf Ax}\odot {\bf b}} with \eqn{\odot\in\{<,\leq,==\}},
@@ -86,14 +80,14 @@ echelon.matrix <- function(E, tol=sqrt(.Machine$double.eps),...){
 #'
 #' Note that the resulting \code{\link{editmatrix}} may be inconsistent because of inconsistencies in
 #' \eqn{\tilde{\bf x}}.
-#' 
+#' @aliases replaceValue
 #' @param E \code{editmatrix} object
 #' @param var \code{character} with name of variable
 #' @param value \code{numeric} with value of variable
 #' @return reduced edit matrix 
 #'
 #' @export
-replaceValue <- function(E, var, value){
+substValue <- function(E, var, value){
     v <- match(var, getVars(E), nomatch=0)
     if (v==0){
         stop("Parameter var (", var, ") is not a variable of editmatrix E")
@@ -103,4 +97,12 @@ replaceValue <- function(E, var, value){
     E[,ib] <- E[ ,ib] - E[ ,v]*value
     E[,v] <- 0
     E[!isObviouslyRedundant(E),]
-}
\ No newline at end of file
+}
+
+#' @nord
+#' @export
+replaceValue <- function(...){
+    warning("replaceValue is deprecated. Use substValue in stead.")
+    substValue(...)
+}
+
